@@ -281,6 +281,9 @@ impl<'s> sop::SOP<'s> for SQOP<'s> {
     fn version(&'s self) -> Result<Box<dyn sop::ops::Version + 's>> {
         Ok(Box::new(Version {}))
     }
+    fn sopv_version(&'s self) -> Result<&'static str> {
+        Ok("1.0")
+    }
     fn generate_key(&'s self)
         -> Result<Box<dyn sop::ops::GenerateKey<SQOP, Keys> + 's>>
     {
@@ -935,9 +938,6 @@ impl<'s> Encrypt<'s> {
                 SymmetricAlgorithm::Camellia128,
                 SymmetricAlgorithm::Blowfish,
                 SymmetricAlgorithm::Twofish,
-                SymmetricAlgorithm::CAST5,
-                SymmetricAlgorithm::IDEA,
-                SymmetricAlgorithm::TripleDES,
             ].iter().copied().filter(|&a| {
                 a.is_supported() && sqop.policy.symmetric_algorithm(a).is_ok()
             }).collect(),
@@ -1210,7 +1210,7 @@ impl<'s> sop::ops::Ready<(Option<sop::SessionKey>, Vec<sop::ops::Verification>)>
             } else {
                 Box::new(io::sink())
             },
-            if self.decrypt.verify.certs.is_empty() { 0 } else { 1 },
+            0,
             self.decrypt.verify.not_before,
             self.decrypt.verify.not_after,
             self.decrypt.verify.certs);
@@ -2085,7 +2085,11 @@ fn sop_error(e: anyhow::Error) -> Error {
     };
 
     let e = match e.downcast::<io::Error>() {
-        Ok(e) => return e.into(),
+        Ok(e) => return if e.kind() == io::ErrorKind::UnexpectedEof {
+            Error::BadData
+        } else {
+            e.into()
+        },
         Err(e) => e,
     };
 
@@ -2191,4 +2195,24 @@ mod tests {
 
         Ok(())
     }
+
+    #[test]
+    fn issue_29() -> Result<()> {
+        let sop = SQOP::default();
+
+        let alice_sec = sop.generate_key()?
+            .userid("Alice Lovelace <alice@openpgp.example>")
+            .generate()?;
+        let alice_pgp = sop.extract_cert()?
+            .keys(&alice_sec)?;
+
+        let no_signature = b"\n";
+        assert!(matches!(sop.inline_verify()?
+                         .certs(&alice_pgp)?
+                         .message(&mut Cursor::new(&no_signature))
+                         .and_then(|ready| ready.to_vec()),
+                         Err(sop::errors::Error::BadData)));
+
+        Ok(())
+    }
 }
